searchData={"items":[{"type":"module","title":"Mash","doc":"Mash is a dead simple tool for defining and running CI pipelines in Elixir.","ref":"Mash.html"},{"type":"module","title":"Dependencies - Mash","doc":"- Elixir\n- Mix\n- The unix `script` utility","ref":"Mash.html#module-dependencies"},{"type":"module","title":"Installation - Mash","doc":"Add mash to your dependencies like so:\n\n```elixir\ndef deps do\n  [\n    {:mash, \"~> 0.1.2\"}\n  ]\nend\n```","ref":"Mash.html#module-installation"},{"type":"module","title":"Configuring pipelines - Mash","doc":"To configure your job pipeline, create a `.mash.exs` file at the root of your project containing a module which implements a `jobs/0` function:\n\n```elixir\ndefmodule MashConfig do\n  import Mash.Helpers\n\n  def jobs do\n    [\n      %{\n        name: :test,\n        run: mix(\"test\")\n      },\n      %{\n        name: :credo,\n        run: mix(\"credo\", [\"--all\"])\n      },\n      %{\n        name: :function_example,\n        run: fn _io_pid ->\n          IO.puts(\"Hurray!\")\n        end\n      }\n    ]\n  end\nend\n```\n\nEach entry in the jobs list must, at a minimum, have two keys:\n\n- `:name` -- the name of the job which must be a unique atom\n- `:run` -- a function which defines the work for the job to do. We recommend using the helper functions from Mash.Helpers to define your run function, as they ensure that your function handles setup and teardown correctly for many common scenarios, e.g.:\n    - `Mash.Helpers.mix(task_name, args)` -- execute a mix task with the given `task_name` and `args`.\n    - `Mash.Helpers.shell(command, args)` -- run an executable/script named `command` with `args`.\n    - Or you can pass a function with arity 1.\n      - The function should return `:ok` or `{:ok, value}` if the job succeeds, or `{:error, error}` if the job fails.\n      - The argument passed to your function will be the PID of the IO device which is capturing IO. Since we make this PID the \"group leader\" for your job automatically, you can probably ignore this argument, but you may need to for interfacing with certain libraries that\n      require you to pass an io device PID directly.\n\nOptionally, a job may also contain a key `needs` whose value is an array of other jobs that must pass before this job will be run.\n\nSee [the docs for Mash.Job](https://hexdocs.pm/mash/Mash.Job.html) for more details, including conditional execution.","ref":"Mash.html#module-configuring-pipelines"},{"type":"module","title":"Running - Mash","doc":"```shell\nmix mash\n```","ref":"Mash.html#module-running"},{"type":"module","title":"Full Documentation - Mash","doc":"Full documentation is available on [HexDocs](https://hexdocs.pm/mash).","ref":"Mash.html#module-full-documentation"},{"type":"behaviour","title":"Mash.Config","doc":"Configuration module backed by an agent.","ref":"Mash.Config.html"},{"type":"function","title":"Mash.Config.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Mash.Config.html#child_spec/1"},{"type":"function","title":"Mash.Config.jobs/0","doc":"","ref":"Mash.Config.html#jobs/0"},{"type":"callback","title":"Mash.Config.jobs/0","doc":"","ref":"Mash.Config.html#c:jobs/0"},{"type":"function","title":"Mash.Config.module/0","doc":"","ref":"Mash.Config.html#module/0"},{"type":"function","title":"Mash.Config.start_link/0","doc":"","ref":"Mash.Config.html#start_link/0"},{"type":"module","title":"Mash.Execution","doc":"Wraps execution of a job run function in a Task and a StringIO for tracking output.","ref":"Mash.Execution.html"},{"type":"function","title":"Mash.Execution.run/1","doc":"","ref":"Mash.Execution.html#run/1"},{"type":"module","title":"Mash.Helpers","doc":"Helpers that provide a simple way to write Mash configs.","ref":"Mash.Helpers.html"},{"type":"function","title":"Mash.Helpers.mix/3","doc":"Create a run function for a job that executes a mix task with name `task_name` and the arguments `args`.\n\nAvailable opts:\n- `:env` -- a list of {key, value} pairs that will be used as environment variables.","ref":"Mash.Helpers.html#mix/3"},{"type":"function","title":"Mash.Helpers.restore_cache/1","doc":"Restore a cache file.\n\n- `name` is the base name of the archive to save (default: \".mash-cache\")","ref":"Mash.Helpers.html#restore_cache/1"},{"type":"function","title":"Mash.Helpers.save_cache/2","doc":"Save a cache file as a gzipped tar archive. We use tar because it preserves timestamps which are used\nby Elixir for determining \"staleness\" of compilation.\n\n- `name` is the base name of the archive to save (default: `\".mash-cache\"`)\n- `files` is the list of files/directories to save in the archive (default:` [\"deps\", \"_build\"]`)","ref":"Mash.Helpers.html#save_cache/2"},{"type":"function","title":"Mash.Helpers.shell/3","doc":"Create a run function which executes the script/binary named `command` with the arguments `args`.\n\nAvailable opts:\n- `:env` -- a list of {key, value} pairs that will be used as environment variables.","ref":"Mash.Helpers.html#shell/3"},{"type":"module","title":"Mash.Job","doc":"Structure that represents the configuration and status of one Mash job.\n\nKeys:\n- `:name`: an atom which is the name of the job. It should be unique in the job list.\n- `:if`: either a function w/ arity 1 or a plain value. The job will be run if the value is truthy         or the function returns true. Otherwise it will be skipped. The argument to an if function is the runner's         job list.\n- `:needs`: a list of job name atoms which are required before running this job. If a dependency fails or is skipped,            this job will be skipped. You can also include `{job_name, :optional}` to indicate an optional dependency.            Optional dependencies do not block a job from running if they are skipped, only if they fail.\n- `:run`: a function with arity 1 that is the code to be executed for the job. See `Mash.Helpers` for shortcut functions.         The argument to the run function is the PID of the IO device which is capturing the output of this job. You         probably don't need this, but you might need it for certain libaries that need to be passed an explicit IO PID.\n- `:env`: an array of `{string, string}` pairs which represent ENV variables (name first, then value).","ref":"Mash.Job.html"},{"type":"function","title":"Mash.Job.from_map/1","doc":"","ref":"Mash.Job.html#from_map/1"},{"type":"function","title":"Mash.Job.validate/1","doc":"","ref":"Mash.Job.html#validate/1"},{"type":"module","title":"Mash.Runner","doc":"The process that runs the jobs through a series of Tasks, writes the IO, and monitors the results.","ref":"Mash.Runner.html"},{"type":"function","title":"Mash.Runner.any_running?/1","doc":"","ref":"Mash.Runner.html#any_running?/1"},{"type":"function","title":"Mash.Runner.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Mash.Runner.html#child_spec/1"},{"type":"function","title":"Mash.Runner.if?/2","doc":"","ref":"Mash.Runner.html#if?/2"},{"type":"function","title":"Mash.Runner.start_link/1","doc":"","ref":"Mash.Runner.html#start_link/1"},{"type":"function","title":"Mash.Runner.tick/0","doc":"","ref":"Mash.Runner.html#tick/0"},{"type":"function","title":"Mash.Runner.tick_job/2","doc":"","ref":"Mash.Runner.html#tick_job/2"},{"type":"type","title":"Mash.Runner.job_state/0","doc":"","ref":"Mash.Runner.html#t:job_state/0"},{"type":"type","title":"Mash.Runner.result/0","doc":"","ref":"Mash.Runner.html#t:result/0"},{"type":"task","title":"mix mash","doc":"Task to run Mash jobs.","ref":"Mix.Tasks.Mash.html"},{"type":"function","title":"Mix.Tasks.Mash.run/1","doc":"","ref":"Mix.Tasks.Mash.html#run/1"}],"content_type":"text/markdown"}